summaryrefslogtreecommitdiffstats
path: root/chrome/common/automation_messages_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/automation_messages_internal.h')
-rw-r--r--chrome/common/automation_messages_internal.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/common/automation_messages_internal.h b/chrome/common/automation_messages_internal.h
index 55020c6..17e1def 100644
--- a/chrome/common/automation_messages_internal.h
+++ b/chrome/common/automation_messages_internal.h
@@ -12,6 +12,7 @@
#include "content/common/navigation_types.h"
#include "googleurl/src/gurl.h"
#include "ipc/ipc_message_macros.h"
+#include "net/base/cert_status_flags.h"
#include "net/url_request/url_request_status.h"
#include "ui/gfx/rect.h"
#include "webkit/glue/window_open_disposition.h"
@@ -552,15 +553,15 @@ IPC_MESSAGE_ROUTED1(AutomationMsg_DidNavigate,
// Response:
// - bool: whether the operation was successful.
// - SecurityStyle: the security style of the tab.
// - int: the status of the server's ssl cert (0 means no errors or no ssl
// was used).
// - int: the insecure content state, 0 means no insecure contents.
IPC_SYNC_MESSAGE_CONTROL1_4(AutomationMsg_GetSecurityState,
int,
bool,
SecurityStyle,
- int,
+ net::CertStatus,
int)
// This message requests the page type of the page displayed in the specified
@@ -552,15 +553,15 @@ IPC_MESSAGE_ROUTED1(AutomationMsg_DidNavigate,
// - bool: whether the operation was successful.
// - SecurityStyle: the security style of the tab.
-// - int: the status of the server's ssl cert (0 means no errors or no ssl
-// was used).
+// - net::CertStatus: the status of the server's ssl cert (0 means no errors or
+// no ssl was used).
// - int: the insecure content state, 0 means no insecure contents.
IPC_SYNC_MESSAGE_CONTROL1_4(AutomationMsg_GetSecurityState,